==> haskell-gi-cairo-connector-0.1.1-305-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-EyrfjUCMp82FG80AfoXmIM
key:                  gi-cairo-connector-0.1.1-EyrfjUCMp82FG80AfoXmIM
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  5cdab63ee389e97f1c6c97cdee400543
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-EyrfjUCMp82FG80AfoXmIM
depends:
    base-4.18.2.1 gi-cairo-1.0.30-JvrMs0LU63XF0FZSBbee7J
    gi-cairo-render-0.1.2-A9Nry2lvrWG67ohsW0bHB
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA mtl-2.3.1

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-cairo-connector-0.1.1-306-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-16jVEhb1XppLGgNrWp2GkA
key:                  gi-cairo-connector-0.1.1-16jVEhb1XppLGgNrWp2GkA
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  733294aea24bb3794c52e5c8f4eaf4be
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-16jVEhb1XppLGgNrWp2GkA
depends:
    base-4.18.2.1 gi-cairo-1.0.30-3N3cPtJzja7DTX2BJ7V7xB
    gi-cairo-render-0.1.2-2ZkwwnDvqZE7HgzghN0Wyd
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA mtl-2.3.1

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
